summaryrefslogtreecommitdiffstats
path: root/libtdepim/kmailcompletion.h
diff options
context:
space:
mode:
Diffstat (limited to 'libtdepim/kmailcompletion.h')
-rw-r--r--libtdepim/kmailcompletion.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/libtdepim/kmailcompletion.h b/libtdepim/kmailcompletion.h
index d07eb6a3..00db2b8c 100644
--- a/libtdepim/kmailcompletion.h
+++ b/libtdepim/kmailcompletion.h
@@ -33,7 +33,7 @@ namespace KPIM {
* KMailCompletion allows lookup of email addresses by keyword.
* Typically a keywods would be firstname, lastname, nickname or domain.
*/
-class KMailCompletion : public KCompletion
+class KMailCompletion : public TDECompletion
{
Q_OBJECT
@@ -42,12 +42,12 @@ class KMailCompletion : public KCompletion
KMailCompletion();
/**
* Clears internal keyword map and calls KCompletion::clear.
*/
virtual void clear();
/**
* Uses KCompletion::makeCompletion to find email addresses which starts with string.
* ignores keywords.
*
* @returns email address
@@ -57,7 +57,7 @@ class KMailCompletion : public KCompletion
/**
* Specify keywords for email.
*
* Items may be added with KCompletion::addItem, those will only be returned as match if they
* are in one of these formats:
* \li contains localpart@domain
* \li contains <email>
@@ -42,12 +42,12 @@ class KMailCompletion : public KCompletion
KMailCompletion();
/**
- * Clears internal keyword map and calls KCompletion::clear.
+ * Clears internal keyword map and calls TDECompletion::clear.
*/
virtual void clear();
@@ -42,12 +42,12 @@ class KMailCompletion : public KCompletion
virtual void clear();
/**
- * Uses KCompletion::makeCompletion to find email addresses which starts with string.
+ * Uses TDECompletion::makeCompletion to find email addresses which starts with string.
* ignores keywords.
*
@@ -57,7 +57,7 @@ class KMailCompletion : public KCompletion
* Specify keywords for email.
*
- * Items may be added with KCompletion::addItem, those will only be returned as match if they
+ * Items may be added with TDECompletion::addItem, those will only be returned as match if they
* are in one of these formats:
* \li contains localpart@domain